==> ServiceDesk-0.3.zip: ServiceDesk/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Service Desk';
$lang['friendlynamegold'] = 'Service Desk Gold';
$lang['friendlynamesilver'] = 'Service Desk Silver';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'All Service Desk material removed. If attachments where available, these are not removed.';
$lang['really_uninstall'] = 'Really? Are you sure you want to unsinstall module Service Desk?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'Service desk to support incidents and requests';
$lang['apply'] = 'Apply';
$lang['cancel'] = 'Cancel';
$lang['delete'] = 'Delete';
$lang['edit'] = 'Edit';
$lang['reset'] = 'Reset';
$lang['submit'] = 'Submit';

$lang['error'] = 'Error!';
$land['admin_title'] = 'Service Desk Admin Panel';
$lang['admindescription'] = 'Service Desk system with front end entry of incidents and requests. Mail integrated for communicating status changes to customer.';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Thanks for installing Service Desk. Make sure to set the "Use ServiceDesk" permissions to use this module!';

$lang['addcategory'] = 'Add category';
$lang['addincident'] = 'Add incident';
$lang['addincidentnote'] = 'Add note';
$lang['addstatus'] = 'Add status';
$lang['addtemplate'] = 'Add template';
$lang['allopen'] = 'All open';
$lang['areyousurecategory'] = 'Are you sure you want to delete the category';
$lang['areyousureincident'] = 'Are you sure you want to delete the incident';
$lang['areyousurestatus'] = 'Are you sure you want to delete the status';
$lang['areyousuretemplate'] = 'Are you sure you want to delete the template';
$lang['categories'] = 'Categories';
$lang['category'] = 'Category';
$lang['categoryadded'] = 'Category added';
$lang['categorycode'] = 'Code';
$lang['categorydescription'] = 'Description';
$lang['categorydeleted'] = 'Category deleted';
$lang['categoryupdated'] = 'Category updated';
$lang['code'] = 'Code';
$lang['created'] = 'Created';
$lang['detaildescription'] = 'Detail description';
$lang['fetemplates'] = 'Front end templates';
$lang['firstpage'] = '<<';
$lang['incidentadded'] = 'Incident added';
$lang['incidentdeleted'] = 'Incident deleted';
$lang['incidentdescription'] = 'Short description';
$lang['incident'] = 'Incident';
$lang['incidents'] = 'Incidents';
$lang['incidentsfound'] = 'Incidents found with given filter criteria';
$lang['incidentupdated'] = 'Incident updated';
$lang['lastpage'] = '>>';
$lang['mailsettings'] = 'Mail Settings';
$lang['mailsettingsupdated'] = 'Mail Settings have been updated';
$lang['more'] = 'More';
$lang['newincidentmailsubject2admin'] = 'New incident added via front end';
$lang['newincidentmail2admintemplate'] = 'Mail template that will be used for mail to default owner stating incident has been added';
$lang['newrequestor'] = 'New';
$lang['nextpage'] = '>';
$lang['nocatcodegiven'] = 'No category code given, while this is mandatory';
$lang['nocatdescgiven'] = 'No description given, while this is mandatory';
$lang['nogoldoptions'] = 'No additional options for Gold version';
$lang['noincidentdescgiven'] = 'No description given, while this is mandatory';
$lang['noincidentsfound'] = 'No incidents found';
$lang['nonotegiven'] = 'No note entered, while this is mandatory';
$lang['noreportinfo'] = 'There has been no report prepared for this tab.';
$lang['nosilveroptions'] = 'No additional options for Silver version';
$lang['nostatdescgiven'] = 'No description given, while this is mandatory';
$lang['note'] = 'Note';
$lang['noteadded'] = 'Note added to incident';
$lang['notemplatecontentgiven'] = 'No template content given';
$lang['notemplatenamegiven'] = 'No template name given';
$lang['notloggedin'] = 'You are not logged in yet, please login.';
$lang['numberofincidents'] = 'Number of open incidents';
$lang['openincidentsnone'] = 'There are no incidents to take care of';
$lang['openincidentsone'] = 'There is one incident that needs action';
$lang['openincidents'] = 'There are %s incidents that need action';
$lang['options'] = 'Options';
$lang['optionsupdated'] = 'Options updated';
$lang['overwritewarning'] = 'This will overwrite existing information';
$lang['owner'] = 'Owner';
$lang['parametershide'] = 'Hide';
$lang['parametersshow'] = 'Show';
$lang['periodfrom'] = 'Period from';
$lang['periodto'] = 'To';
$lang['prevpage'] = '<';
$lang['priority'] = 'Priority';
$lang['priorityhigh'] = 'High';
$lang['prioritylow'] = 'Low';
$lang['prioritymedium'] = 'Medium';
$lang['priorityseq'] = 'Priority sequence';
$lang['product'] = 'Product';
$lang['prompt_of'] = 'of';
$lang['prompt_page'] = 'Page';
$lang['receivedincidentmailsubject'] = 'Received incident follow up';
$lang['receiveincidentmailtemplate'] = 'Mail template that will be used for mail to requestor stating incident has been received';
$lang['requestor'] = 'Requestor';
$lang['requestor_ref'] = 'Reference';
$lang['requestor_reference'] = 'Reference of requestor';
$lang['restoredefaults'] = 'Restore %s Templates';
$lang['sendmailincident'] = 'Send mail after logging?';
$lang['sendmail'] = 'Send mail when status set?';
$lang['status'] = 'Status';
$lang['statusadded'] = 'Status added';
$lang['statusdeleted'] = 'Status deleted';
$lang['statusdescription'] = 'Description';
$lang['statusses'] = 'Statusses';
$lang['statussettoclosedmailsubject'] = 'Incident has been closed';
$lang['statusupdated'] = 'Status updated';
$lang['subjectnewincident'] = 'Your incident has been received';
$lang['subjectnewincident2admin'] = 'New incident added';
$lang['templateadded'] = 'Template added';
$lang['templatecontent'] = 'Content';
$lang['templatedeleted'] = 'Template deleted';
$lang['templatename'] = 'Template name';
$lang['templatessilverrestored'] = 'Templates: form_FEList_Silver, form_FEDetail_Silver have been restored';
$lang['templateupdated'] = 'Template updated';
$lang['title_allowchangerequestor'] = 'Allow that requestor on incident may be changed';
$lang['title_categories'] = 'Categories';
$lang['title_default_fetemplate'] = 'Default front end form';
$lang['title_default_owner'] = 'Default incident owner';
$lang['title_default_status'] = 'Default status';
$lang['title_defaultdetailtemplate'] = 'Front End template for details';
$lang['title_defaulttemplate'] = 'Template to use on Front End list';
$lang['title_description'] = 'Description';
$lang['title_enableeditor'] = 'Enable WYSIWYG editor';
$lang['title_enablemailwysiwyg'] = 'Enable WYSIWYG on mail body settings';
$lang['title_fesubmit_redirect'] = 'Page that requestor returns to';
$lang['title_fieldset_mail'] = 'Mail settings';
$lang['title_htmlmail'] = 'Send as HTML mail';
$lang['title_incident_filter'] = 'Incident filter';
$lang['title_incidentdetail'] = 'Detail';
$lang['title_incidents'] = 'Incidents';
$lang['title_incidentsbyperiod'] = 'Incidents by period';
$lang['title_mail_template'] = 'Content';
$lang['title_mail_subject'] = 'Subject';
$lang['title_modified'] = 'Modified';
$lang['title_note'] = 'Note';
$lang['title_notedate'] = 'Date';
$lang['title_notes'] = 'Notes';
$lang['title_noteuser'] = 'User';
$lang['title_options'] = 'Options';
$lang['title_optionsgold'] = 'Options Gold';
$lang['title_optionssilver'] = 'Options Silver';
$lang['title_pagelimit'] = 'Page limit for back end listings';
$lang['title_parms_to_use'] = 'Available Parameters';
$lang['title_priorityseq'] = 'Prio Seq';
$lang['title_report_filter'] = 'Report filter';
$lang['title_restoretemplates'] = 'Restore original templates';
$lang['title_sendmailincident'] = 'Send mail after logging?';
$lang['title_sendmailincident2admin'] = 'Send mail to default owner on new incident?';
$lang['title_statusses'] = 'Statusses';
$lang['title_templatename'] = 'Name';
$lang['unknown_display'] = 'Unknown value for parameter display used. Please notify webmaster.';
$lang['unlimited'] = 'Unlimited';
$lang['yearfrom'] = 'Year from';
$lang['yearto'] = 'To';

$lang['helpdetailpage'] = 'The parameter allows you to pass the detail page alias name in which
the detail will be shown';

$lang['help'] = '<h3>What Does This Do?</h3>
<p>Service desk to support incidents and requests</p>
<h3>How Do I Use It</h3>
<p>Enter a number of statusses if the default installed ones are not enough.<br>
The status \'CL\' (closed) that is prepared during installation is a special one. You are not able to delete it. It is 
used in the filtering of the list of incidents.<br />
Only incidents that do not have the status \'CL\' are shown. Next to this 
if you set the status of an incident to \'CL\', the system will set the current date/time as the end date/time on the incident. 
This will be used for statistics.</p>
<p>One category is created during installation. Add other categories to your liking. A category can be selected on the front end.<br>
There are a number of priorities, each can have a score. As a basis <a href="http://www.itsmsolutions.com/newsletters/DITYvol3iss1.htm">
www.itsmsolutions.com/newsletters/DITYvol3iss1.htm</a> has
been used for defining the scores.<br>
Check the usage of the various options. The \'Enable WYSIWYG editor\' overrules the user setting. Turning this parameter of, allows 
quicker entry of information, since the usage of the Tab key works quick.</p>
<p>If you want to have customers enter incidents/requests.<br>
On one of you pages use: {cms_module module=ServiceDesk action=fesubmit}<br>
Visitor should log in, commences to this page (so best is to use custom content in this situation).<br>
Customer enters request/complain and this will be saved in Service Desk.<br> 
Back end employee(s) notices new incident due to mail or a regular check.<br> 
Owner of incident opens it and adds notes. Once ready, set the status to closed and is done.</p>
<p>Templates for mail send to both requestor and incident owner (from service desk) are prepared during installation. Module CMSMailer
should work to have the mails send.</p>
<h3>What Parameters Does It Take</h3>
<p>The front end has one parameter: action=fesubmit. This allows a customer/requestor, once logged in, to enter an incident.
If a requestor has entered an incident, a mail can be send as a confirmation.</p>
<h3>Additional functionality</h3>
<p>More functions will be made available via commercial parts. These will be the Silver and the Gold versions. 
See for the versions <a href="http://www.duketown.eu/shop">the Duketown shop</a>.</p>
<ul>
  <li>Silver:</li>
  <ul>
    <li>Per user filters are possible over the incidents;</li>
    <li>Front End shows more information when logged in;</li>
    <li>Report on the incidents per month.</li>
  </ul>
</ul>
<h3>Notes</h3>
<ul>
  <li>When module jQueryTools is installed, the lists in the back end are sortable.</li>
</ul>
<h3>Support</h3>
<p>Visit the website of <a href="http://www.duketown.eu">Duketown System Consultancy</a> for more information on modules.
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2009-2011, Duketown <a href="mailto:cmsms@duketown.eu">&lt;cmsms@duketown.eu&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
?>

==> ServiceDesk-0.8.zip: ServiceDesk/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Service Desk';
$lang['friendlynamegold'] = 'Service Desk Gold';
$lang['friendlynamesilver'] = 'Service Desk Silver';
$lang['postinstall'] = 'Post Install Message.';
$lang['postuninstall'] = 'All Service Desk material removed. If attachments where available, these are not removed.';
$lang['really_uninstall'] = 'Really? Are you sure you want to uninstall module Service Desk?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['upgraded'] = 'Module upgraded to version %s.';
$lang['moddescription'] = 'Service desk to support incidents and requests';
$lang['areyousure'] = 'Are you sure to delete this?';
$lang['apply'] = 'Apply';
$lang['cancel'] = 'Cancel';
$lang['delete'] = 'Delete';
$lang['edit'] = 'Edit';
$lang['reset'] = 'Reset';
$lang['submit'] = 'Submit';

$lang['error'] = 'Error!';
$land['admin_title'] = 'Service Desk Admin Panel';
$lang['admindescription'] = 'Service Desk system with front end entry of incidents and requests. Mail integrated for communicating status changes to customer.';
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['postinstall'] = 'Thanks for installing Service Desk. Make sure to set the "Use ServiceDesk" permissions to use this module!';

$lang['addattribute'] = 'Add attribute';
$lang['addcategory'] = 'Add category';
$lang['addincident'] = 'Add incident';
$lang['addincidentnote'] = 'Add note';
$lang['addstatus'] = 'Add status';
$lang['addtemplate'] = 'Add template';
$lang['adduseraccount'] = 'Add requestor';
$lang['allopen'] = 'All open';
$lang['areyousurecategory'] = 'Are you sure you want to delete the category';
$lang['areyousureincident'] = 'Are you sure you want to delete the incident';
$lang['areyousurestatus'] = 'Are you sure you want to delete the status';
$lang['areyousuretemplate'] = 'Are you sure you want to delete the template';
$lang['attrcheckbox'] = 'Checkbox';
$lang['attrdropdown'] = 'Dropdown';
$lang['attrfiletext'] = 'File';
$lang['attributeadded'] = 'Attribute has been added';
$lang['attributedeleted'] = 'Attribute has been deleted';
$lang['attributeupdated'] = 'Attribute has been updated';
$lang['attrimagetext'] = 'Image';
$lang['attrmove_down'] = 'Move this down';
$lang['attrmove_up'] = 'Move this up';
$lang['attrtextarea'] = 'Text area';
$lang['attrtextbox'] = 'Text box';
$lang['attrtext_hide'] = 'Hide from front end';
$lang['attrtext_show'] = 'Show on front end';
$lang['categories'] = 'Categories';
$lang['category'] = 'Category';
$lang['categoryadded'] = 'Category added';
$lang['categorycode'] = 'Code';
$lang['categorydescription'] = 'Description';
$lang['categorydeleted'] = 'Category deleted';
$lang['categoryupdated'] = 'Category updated';
$lang['chartclosuretimebyprio'] = 'Time to Close by Priority (days)';
$lang['chartopenedclosedbymonth'] = 'Opened/Closed last Year';
$lang['chartopenincbycategory'] = 'Open Incidents by Category';
$lang['chartopenincbymonth'] = 'Open Incidents By Month';
$lang['chartcaugeopenpriohigh'] = 'Open Incidents Priority High (%s)';
$lang['chartcaugeopenpriolow'] = 'Open Incidents Priority Low (%s)';
$lang['chartcaugeopenpriomedium'] = 'Open Incidents Priority Medium (%s)';
$lang['chartstatusclosed'] = 'Closed';
$lang['chartstatusopened'] = 'Opened';
$lang['code'] = 'Code';
$lang['couldnotload'] = 'Not able to load file: %s';
$lang['created'] = 'Created';
$lang['detaildescription'] = 'Detail description';
$lang['error_customer_group_unknown'] = 'Default customer group is not set in options';
$lang['error_filesize'] = 'The size of the file is not allowed (to big)';
$lang['error_invalidfiletype'] = 'The file to upload is not an allowed file type';
$lang['error_invalidimagetype'] = 'The file to upload is not an allowed image type';
$lang['error_mkdir'] = 'Error occured while creating';
$lang['error_movefile'] = 'An error occured while moving the file to: ';
$lang['fetemplates'] = 'Front end templates';
$lang['firstpage'] = '<<';
$lang['incidentadded'] = 'Incident added';
$lang['incidentdeleted'] = 'Incident deleted';
$lang['incidentdescription'] = 'Short description';
$lang['incident'] = 'Incident';
$lang['incidents'] = 'Incidents';
$lang['incidentsfound'] = 'Incidents found with given filter criteria';
$lang['incidentupdated'] = 'Incident updated';
$lang['installsilver'] = 'Install';
$lang['jqpnotinstalled'] = 'Module JQueryPlot not installed, which is needed to present graph(s).';
$lang['lastpage'] = '>>';
$lang['mailsettings'] = 'Mail Settings';
$lang['mailsettingsupdated'] = 'Mail Settings have been updated';
$lang['more'] = 'More';
$lang['newincidentmailsubject2admin'] = 'New incident added via front end';
$lang['newincidentmail2admintemplate'] = 'Mail template that will be used for mail to default owner stating incident has been added';
$lang['newrequestor'] = 'New';
$lang['nextpage'] = '>';
$lang['noattrnamegiven'] = 'No attribute name given, while this is mandatory';
$lang['nocatcodegiven'] = 'No category code given, while this is mandatory';
$lang['nocatdescgiven'] = 'No description given, while this is mandatory';
$lang['nogoldoptions'] = 'No additional options for Gold version';
$lang['noincidentdescgiven'] = 'No description given, while this is mandatory';
$lang['noincidentsfound'] = 'No incidents found';
$lang['nomaxlengthgiven'] = 'No maximum length given, while this is mandatory';
$lang['nonotegiven'] = 'No note entered, while this is mandatory';
$lang['nooptionsgiven'] = 'No options given. Should be at least one.';
$lang['noreportinfo'] = 'No report has been prepared for this tab (install the Silver extension via Options Gold tab).';
$lang['nosilveroptions'] = 'No additional options for Silver version (install the Silver extension via Options Gold tab).';
$lang['nostatdescgiven'] = 'No description given, while this is mandatory';
$lang['note'] = 'Note';
$lang['noteadded'] = 'Note added to incident';
$lang['notemplatecontentgiven'] = 'No template content given';
$lang['notemplatenamegiven'] = 'No template name given';
$lang['notloggedin'] = 'You are not logged in yet, please login.';
$lang['numberofincidents'] = 'Number of open incidents';
$lang['openincidentsnone'] = 'There are no incidents to take care of';
$lang['openincidentsone'] = 'There is one incident that needs action';
$lang['openincidents'] = 'There are %s incidents that need action';
$lang['options'] = 'Options';
$lang['optionsupdated'] = 'Options updated';
$lang['overwritewarning'] = 'This will overwrite existing information';
$lang['owner'] = 'Owner';
$lang['parametershide'] = 'Hide';
$lang['parametersshow'] = 'Show';
$lang['periodfrom'] = 'Period from';
$lang['periodto'] = 'To';
$lang['prevpage'] = '<';
$lang['priority'] = 'Priority';
$lang['priorityhigh'] = 'High';
$lang['prioritylow'] = 'Low';
$lang['prioritymedium'] = 'Medium';
$lang['priorityseq'] = 'Priority sequence';
$lang['product'] = 'Product';
$lang['prompt_of'] = 'of';
$lang['prompt_page'] = 'Page';
$lang['receivedincidentmailsubject'] = 'Received incident follow up';
$lang['receiveincidentmailtemplate'] = 'Mail template that will be used for mail to requestor stating incident has been received';
$lang['requestor'] = 'Requestor';
$lang['requestor_ref'] = 'Reference';
$lang['requestor_reference'] = 'Reference of requestor';
$lang['restoredefaults'] = 'Restore %s Templates';
$lang['sendmailincident'] = 'Send mail after logging?';
$lang['sendmail'] = 'Send mail when status set?';
$lang['silverextensioninstalled'] = 'The Silver extension has been installed';
$lang['status'] = 'Status';
$lang['statusadded'] = 'Status added';
$lang['statusdeleted'] = 'Status deleted';
$lang['statusdescription'] = 'Description';
$lang['statusses'] = 'Statusses';
$lang['statussettoclosedmailsubject'] = 'Incident has been closed';
$lang['statusupdated'] = 'Status updated';
$lang['subjectnewincident'] = 'Your incident has been received';
$lang['subjectnewincident2admin'] = 'New incident added';
$lang['templateadded'] = 'Template added';
$lang['templatecontent'] = 'Content';
$lang['templatedeleted'] = 'Template deleted';
$lang['templatename'] = 'Template name';
$lang['templatessilverrestored'] = 'Templates: form_FEList_Silver, form_FEDetail_Silver have been restored';
$lang['templateupdated'] = 'Template updated';
$lang['title_adduseraccount'] = 'Add new requestor';
$lang['title_attribute'] = 'Attribute';
$lang['title_attributes'] = 'Attributes';
$lang['title_allowchangerequestor'] = 'Allow that requestor on incident may be changed';
$lang['title_allowedfiletypes'] = 'Allowed file type extensions for attributes (use a comma as separator)';
$lang['title_allowedimagetypes'] = 'Allowed image type extensions for attributes (use a comma as separator)';
$lang['title_categories'] = 'Categories';
$lang['title_default_fetemplate'] = 'Default front end form';
$lang['title_default_owner'] = 'Default incident owner';
$lang['title_default_status'] = 'Default status';
$lang['title_defaultdetailtemplate'] = 'Front End template for details';
$lang['title_defaulttemplate'] = 'Template to use on Front End list';
$lang['title_description'] = 'Description';
$lang['title_enableeditor'] = 'Enable WYSIWYG editor';
$lang['title_enablemailwysiwyg'] = 'Enable WYSIWYG on mail body settings';
$lang['title_fesubmit_redirect'] = 'Page that requestor returns to';
$lang['title_fieldset_mail'] = 'Mail settings';
$lang['title_gaugelowlevel'] = 'Gauge Priority Low Minimum/Maximum/Color';
$lang['title_gaugemedlevel'] = 'Gauge Priority Medium Minimum/Maximum/Color';
$lang['title_gaugehighlevel'] = 'Gauge Priority High Minimum/Maximum/Color';
$lang['title_golddashboard'] = 'Dashboard';
$lang['title_htmlmail'] = 'Send as HTML mail';
$lang['title_incident_filter'] = 'Incident filter';
$lang['title_incidentdetail'] = 'Detail';
$lang['title_incidents'] = 'Incidents';
$lang['title_incidentsbyperiod'] = 'Incidents by period';
$lang['title_installsilver'] = 'Install silver extension';
$lang['title_mail_template'] = 'Content';
$lang['title_mail_subject'] = 'Subject';
$lang['title_maxlength'] = 'Maximum length';
$lang['title_modified'] = 'Modified';
$lang['title_note'] = 'Note';
$lang['title_notedate'] = 'Date';
$lang['title_notes'] = 'Notes';
$lang['title_noteuser'] = 'User';
$lang['title_options'] = 'Options';
$lang['title_optionsgold'] = 'Options Gold';
$lang['title_optionssilver'] = 'Options Silver';
$lang['title_pagelimit'] = 'Page limit for back end listings';
$lang['title_parms_to_use'] = 'Available Parameters';
$lang['title_priorityseq'] = 'Prio Seq';
$lang['title_prompt'] = 'Prompt';
$lang['title_public'] = 'Public';
$lang['title_report_filter'] = 'Report filter';
$lang['title_restoretemplates'] = 'Restore original templates';
$lang['title_selectone'] = 'Select the type';
$lang['title_sendmailincident'] = 'Send mail after logging?';
$lang['title_sendmailincident2admin'] = 'Send mail to default owner on new incident?';
$lang['title_sendashtml'] = 'Send mail as html?';
$lang['title_statusses'] = 'Statusses';
$lang['title_templatename'] = 'Name';
$lang['title_type'] = 'Type';
$lang['unknown_display'] = 'Unknown value for parameter display used. Please notify webmaster.';
$lang['unlimited'] = 'Unlimited';
$lang['yearfrom'] = 'Year from';
$lang['yearto'] = 'To';

$lang['helpdetailpage'] = 'The parameter allows you to pass the detail page alias name in which
the detail will be shown';
$lang['helpformtemplate'] = 'Use the formtemplate parameter to set the correct template to use for 
front end entry/list of incidents. Don\'t include prefix \'form_\'.';

$lang['help'] = '<h3>What Does This Do?</h3>
<p>Service desk to support incidents and requests</p>
<h3>How Do I Use It</h3>
<p>Enter a number of statusses if the default installed ones are not enough.<br>
The status \'CL\' (closed) that is prepared during installation is a special one. You are not able to delete it. It is 
used in the filtering of the list of incidents.<br />
Only incidents that do not have the status \'CL\' are shown. Next to this 
if you set the status of an incident to \'CL\', the system will set the current date/time as the end date/time on the incident. 
This will be used for statistics.</p>
<p>One category is created during installation. Add other categories to your liking. A category can be selected on the front end.<br>
There are a number of priorities, each can have a score. As a basis <a href="http://www.itsmsolutions.com/newsletters/DITYvol3iss1.htm">
www.itsmsolutions.com/newsletters/DITYvol3iss1.htm</a> has
been used for defining the scores.<br>
Check the usage of the various options. The \'Enable WYSIWYG editor\' overrules the user setting. Turning this parameter of, allows 
quicker entry of information, since the usage of the Tab key works quick.</p>
<p>If you want to have customers enter incidents/requests.<br>
On one of you pages use: {cms_module module=ServiceDesk action=fesubmit}<br>
Visitor should log in, commences to this page (so best is to use custom content in this situation).<br>
Customer enters request/complain and this will be saved in Service Desk.<br> 
Back end employee(s) notices new incident due to mail or a regular check.<br>
If incidents are entered via the back end and the requestor contains \'New\', there has been no 
user set up via Front End Users.<br />
Owner of incident opens it and adds notes. Once ready, set the status to closed and is done.</p>
<p>Templates for mail send to both requestor and incident owner (from service desk) are prepared during installation. Module CMSMailer
should work to have the mails send.</p>
<h3>What Parameters Does It Take</h3>
<p>The front end has one parameter: action=fesubmit. This allows a customer/requestor, once logged in, to enter an incident.
If a requestor has entered an incident, a mail can be send as a confirmation.</p>
<h3>Additional functionality</h3>
<p>More functions will are available via commercial parts. These will be the Silver and the Gold versions. 
See for the versions <a href="http://www.duketown.eu/index.php?page=module-service-desk" target="_blank">the service desk explanation page</a>.</p>
<ul>
  <li>Silver:</li>
  <ul>
    <li>Per user filters are possible over the incidents;</li>
    <li>Front End shows more information when logged in;</li>
    <li>For more detail, see the <a href="http://www.duketown.eu/index.php?page=dtsd_silver" target="_blank">silver support page</a>;</li>
    <li>Report on the incidents per month.</li>
  </ul>
  <li>Gold:</li>
  <ul>
    <li>All the options that are mentioned under Silver;</li>
    <li>A dashboard with six charts to monitor the incidents and how the performance was;</li>
    <li>Change of color for the priority bullets on the list of incidents.</li>
    <li>For more detail, see the <a href="http://www.duketown.eu/index.php?page=dtsd_gold" target="_blank">gold support page</a>;</li>
    <li><strong>Note:</strong> for the gold extension, you will need to install module JQueryPlot.</li>
  </ul>
</ul>
<h3>Notes</h3>
<ul>
  <li>When module jQueryTools is installed, the lists in the back end are sortable.</li>
</ul>
<h3>Support</h3>
<p>Visit the website of <a href="http://www.duketown.eu">Duketown System Consultancy</a> for more information on modules.
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2008 - '.date("Y").', Duketown. 
<p>Now that you are using this free module, why not make a donation to Duketown! Thanks in advance.
<form target="_blank" action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="AY8JBJZWU7Q7S">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>
</p>
All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>
